@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Text.php,v 1.6.2.18 2004/08/23 12:31:56 jan Exp $
+ * $Horde: horde/lib/Text.php,v 1.6.2.16 2003/08/22 16:25:12 slusarz Exp $
  *
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
@@ -19,7 +19,7 @@ define('TEXT_HTML_NOHTML_NOBREAK', 5);
  * The Text:: class provides common methods for manipulating text.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.6.2.18 $
+ * @version $Revision: 1.6.2.16 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -102,7 +102,7 @@ class Text {
      */
     function wrap($text, $length = 80, $break_char = "\n", $charset = "")
     {
-        $paragraphs = preg_split("/\r?\n/", $text);
+        $paragraphs = explode("\n", $text);
 
         $charset = strtolower($charset);
         switch ($charset) {
@@ -114,12 +114,6 @@ class Text {
                 break;
             default:
                 for ($i = 0; $i < count($paragraphs); $i++) {
-                    /* We need to handle the Usenet-style signature line
-                     * separately; since the space after the two dashes is
-                     * REQUIRED, we don't want to trim the line. */
-                    if ($paragraphs[$i] != '-- ') {
-                        $paragraphs[$i] = rtrim($paragraphs[$i]);
-                    }
                     $paragraphs[$i] = wordwrap($paragraphs[$i], $length, $break_char);
                 }
                 break;
